@@ -79,10 +79,10 @@ def get_outcat_local(outcat):
     return aa
 
 
-def localDenCluster(data_name, para, mask_name=None, outcat_name=None, outcat_wcs_name=None):
+def localDenCluster(data_name, para=None, mask_name=None, outcat_name=None, outcat_wcs_name=None):
     data_port_dir = data_name.replace('.fits', '')
-
-    para = {"gradmin": 0.01, "rhomin": 0.8, "deltamin": 4, "v_min": 27, "rms": 0.46, "sigma": 0.6, "is_plot": 0}
+    if para is None:
+        para = {"gradmin": 0.01, "rhomin": 0.8, "deltamin": 4, "v_min": 27, "rms": 0.46, "sigma": 0.6, "is_plot": 0}
 
     if not os.path.exists(data_port_dir):
         os.mkdir(data_port_dir)
